# Overview

[//]: # (start-badges)

[![version](https://img.shields.io/pypi/v/seveno-pyutil.svg)](https://pypi.org/project/seveno-pyutil/)
[![license](https://img.shields.io/pypi/l/seveno-pyutil.svg)](https://opensource.org/licenses/MIT)
[![python_versions](https://img.shields.io/pypi/pyversions/seveno-pyutil.svg)](https://pypi.org/project/seveno-pyutil/)
[![Codacy](https://app.codacy.com/project/badge/Grade/a753bb4b3b354d94a9b258b91738b571)](https://www.codacy.com/gh/tadams42/seveno_pyutil/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=tadams42/seveno_pyutil&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/tadams42/seveno_pyutil/branch/development/graph/badge.svg?token=gsFuETHxw8)](https://codecov.io/gh/tadams42/seveno_pyutil)
[![travis](https://app.travis-ci.com/tadams42/seveno_pyutil.svg?branch=master)](https://app.travis-ci.com/tadams42/seveno_pyutil)
[![docs](https://readthedocs.org/projects/seveno-pyutil/badge/?style=flat)](https://seveno-pyutil.readthedocs.io/en/latest/)

[//]: # (end-badges)

Various unsorted Python utilities. [Examples of usage](https://seveno-pyutil.readthedocs.io/en/latest/examples_and_usage.html)

## Installation

~~~sh
pip install seveno_pyutil
~~~

## Documentation

~~~sh
python setup.py build_sphinx
~~~

## Tests

~~~sh
py.test
~~~

## Development mode

Install with extra dev packages

~~~sh
pip install -e .[dev]
~~~
